/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.xta;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;
import org.mockito.Spy;

class XtaMessageMetaDataMapperTest {

	@Spy
	private final XtaMessageMetaDataMapper mapper = Mappers.getMapper(XtaMessageMetaDataMapper.class);

	@DisplayName("msg status list from soap")
	@Nested
	class TestMsgStatusListFromSoap {

		@Test
		void shouldMap() {
			var response = MsgStatusListTypeAndHeaderResponseTestFactory.create();

			var result = mapper.msgStatusListFromSoap(response);

			assertThat(result).isNotNull();
		}

		@DisplayName("should set moreMessagesAvailable to false")
		@Test
		void shouldSetMoreMessagesAvailableToFalse() {
			var response = MsgStatusListTypeAndHeaderResponseTestFactory.create();

			var result = mapper.msgStatusListFromSoap(response);

			assertThat(result.isMoreMessagesAvailable()).isFalse();
		}
	}
}
